@@ -3,6 +3,7 @@ import csv
 import logging
 import os
 import sys
+import gzip
 from abc import ABC, abstractmethod
 
 from .message import Message
@@ -239,7 +240,9 @@ class FileSource(SourceTap):
     def __init__(self, config, logger=pipelineLogger):
         super().__init__(config, logger)
         if config.infile == "-":
-            self.infile = sys.stdin
+            self.infile = sys.stdin.buffer
+        elif config.infile.endswith(".gz"):
+            self.infile = gzip.open(config.infile)
         else:
             self.infile = open(config.infile, "rb")
         self.repeat = config.repeat
@@ -296,13 +299,18 @@ class FileDestination(DestinationTap):
         else:
             self.filename = config.outfile
 
-        if config.outfile == "-":
-            self.outFile = sys.stdout
+        if self.filename == "-":
+            self.outFile = sys.stdout.buffer
+        elif self.filename.endswith(".gz"):
+            if config.overwrite:
+                self.outFile = gzip.GzipFile(self.filename, "wb")
+            else:
+                self.outFile = gzip.GzipFile(self.filename, "ab")
         else:
             if config.overwrite:
-                self.outFile = open(self.filename, "w")
+                self.outFile = open(self.filename, "wb")
             else:
-                self.outFile = open(self.filename, "a")
+                self.outFile = open(self.filename, "ab")
         self.logger.info("File Destination: %s", self.filename)
 
     def __repr__(self):
@@ -320,8 +328,8 @@ class FileDestination(DestinationTap):
         )
 
     def write(self, message):
-        serialized = message.serialize(no_compress=True)
-        print(serialized.decode("utf-8"), file=self.outFile, flush=True)
+        serialized = message.serialize(no_compress=True) + "\n".encode("utf-8")
+        self.outFile.write(serialized)
         return len(serialized)
 
     def close(self):
