@@ -1,7 +1,6 @@
 import argparse
 import logging
 
-from .exception import PipelineError
 from .helpers import parse_kind
 from .tap import SourceOf, DestinationOf
 
@@ -42,12 +41,6 @@ class Pipeline(object):
         else:
             known, extras = parse_kind(["--kind", kind])
 
-        if known.kind is None:
-            raise PipelineError(
-                "Either set PIPELINE in environment, pass --kind on command line, or "
-                "specify it with kind= in constructor"
-            )
-
         if not noInput:
             self.sources = {}
             self.sourceClass = SourceOf(known.kind)
